/*
 * Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */ 

#ifndef STOREDATABASEAPPUI_H
#define STOREDATABASEAPPUI_H

// INCLUDES
#include <aknappui.h>
#include <d32dbms.h>

// FORWARD DECLARATION
class CStoreDatabaseMainView;
class CFileStore;
class CEmployee;

// CLASS DECLARATION

class CStoreDatabaseAppUi : public CAknAppUi
    {
private:
	enum TStatus
		{
		EStatusUninitialized = 0,
		EStatusCreated,
		EStatusAdded
		};
    
public: // Constructor and destructor
	void ConstructL();
	~CStoreDatabaseAppUi();

public: // From AppUi
	void HandleCommandL(TInt aCommand);
	

	void HandleResourceChangeL(TInt aType);

	
private: // Private methods
	void DoCreateDbL();
	void DoAddDataToDbL();
	void DoReadDataFromDbL();
	void DoDeleteDataFromDbL();

	void CreateDatabaseL(RFs& aFs, const TDesC& aFileName);
	void CreateTableL(RDbDatabase& aDatabase);
	void CreateIndexL(RDbDatabase& aDatabase);
	void AddEmployeeToDatabaseL(RDbDatabase& aDatabase,
			const CEmployee& aEmployee);
	void AddEmployeeToDatabaseUsingSqlL(RDbDatabase& aDatabase,
			const CEmployee& aEmployee);
	void ReadEmployeesFromDatabaseL(RDbDatabase& aDatabase);
	void DeleteEmployeeFromDatabaseL(RDbDatabase& aDatabase,
			const TDesC& aName);
	
private: // Member variables
	CStoreDatabaseMainView* iMainView;
	CFileStore* iFileStore;
	RDbStoreDatabase iDatabase;
	
	RPointerArray<CEmployee> iArray;
	
	TStatus iStatus;
	};

#endif // STOREDATABASEAPPUI_H

// End of File
